---------
function LTC:Announce()
---------
	DEFAULT_CHAT_FRAME:AddMessage(YELLOW_FONT_COLOR_CODE.."LostTreasureCheck |rloaded "..GREEN_FONT_COLOR_CODE..LTC_total.."|r items.");
end

---------
function LTC:HandleSlashCommand(cmd)
---------
	if string.lower(cmd) == "all" then
		LTC:CheckFlags(nil, true);
	elseif string.lower(cmd) == "zone" then
		LTC:CheckFlags(LTC:GetLocationID(), false)
	elseif string.lower(cmd) == "zone all" then
		LTC:CheckFlags(LTC:GetLocationID(), true)
	elseif string.lower(cmd) == "wp clear" or string.lower(cmd) == "waypoint clear" then
		if(TomTom ~= nil) then
			StaticPopup_Show("TOMTOM_REMOVE_ALL_CONFIRM")
		end
	elseif string.lower(cmd) == "wp" or string.lower(cmd) == "waypoint" then
		if(TomTom ~= nil) then
			LTC:AddWayPoints(LTC:GetLocationID())
		else
			DEFAULT_CHAT_FRAME:AddMessage(YELLOW_FONT_COLOR_CODE.."Lost Treasure Check:|r"..RED_FONT_COLOR_CODE.." ERROR|r".." - Waypoints option requires"..GREEN_FONT_COLOR_CODE.."TomTom|r addon.|r");
		end
	else
		LTC:CheckFlags(nil, false);
	end
end

---------
function LTC:GetLocationID()
---------
	SetMapToCurrentZone();
	return GetCurrentMapAreaID();
end

---------
function LTC:CountFlags()
---------
	local count = 0;
	for loc,ids in pairs(LTC_flags)
	do
		for _ in pairs(LTC_flags[loc])
		do
			count = count + 1;
		end
	end
	return count;
end

---------
function LTC:CheckFlags(locationID, showCompleted)
---------
	LTC:PrintHeader();

	local completed = 0;

	if not locationID then
		-- No location specified, show all locations
		if LTC_location_order then
			-- Retrieve locations
			for index, loc in pairs(LTC_location_order)
			do
				completed = completed + LTC:CheckLocationFlags(loc, showCompleted);
				LTC:PrintLocationFooter();
			end
		LTC:PrintFooter(completed);
		end
	else
		-- Show only the specified location
		completed = LTC:CheckLocationFlags(locationID, showCompleted);
		LTC:PrintSeparatorLine();
	end
end

---------
function LTC:CheckLocationFlags(locationID, showCompleted)
---------
	local completed = 0;
	local total = 0;
	local isCompleted = {};
	local orderedFlags = {};

	if locationID then
		-- Retrieve quest flag IDs by location
		if(LTC_flags[locationID]) then
			-- Check if each flag is completed and increment counts
			for questID,info in pairs(LTC_flags[locationID])		
			do								
				total = total + 1;
				if IsQuestFlaggedCompleted(questID) == true then
					isCompleted[questID] = true;
					completed = completed + 1;
				else
					isCompleted[questID] = false;
				end;
				-- Insert flag IDs into a list for sorting later
				table.insert(orderedFlags, questID);
			end

			-- Sort flag IDs to maintain order
			table.sort(orderedFlags);

			LTC:PrintLocationHeader(locationID, total, completed);

			-- Only print this location's header if we have flags to display
			if showCompleted or (total - completed) > 0 then
				LTC:PrintLocationFlags(locationID, orderedFlags, isCompleted, showCompleted);
			end
		else
			LTC:PrintLocationHeader(locationID, 0, 0);
		end
	end

	return completed;
end

---------
function LTC:AddWayPoints(locationID)
---------
	local added = 0;
	local total = 0;	
	
	if(LTC_flags[locationID]) then
		-- Check if each flag is completed and increment counts
		for questID,info in pairs(LTC_flags[locationID])
		do
			if (questID ~= nil) then
				total = total + 1;
				if IsQuestFlaggedCompleted(questID) == false then
					
					local coords = LTC:GetFlagCoords(locationID, questID)
					local note = LTC:GetFlagNote(locationID, questID)
					
					for i,coord in ipairs(coords)
					do
						if coord ~= nil and coord[1] ~= nil and coord[2] ~= nil then
							--TomTom:AddWaypoint(coord[1], coord[2], note, false, true, true, true)  ****** OBSOLETE ******
							TomTom:AddMFWaypoint(locationID, 0, coord[1]/100, coord[2]/100, { title = note })
							added = added + 1;
						end
					end
				end
			end
		end
	end
	
	if (added > 0) then
		TomTom:SetClosestWaypoint()
		DEFAULT_CHAT_FRAME:AddMessage(YELLOW_FONT_COLOR_CODE.."Lost Treasure Check: |r"..GREEN_FONT_COLOR_CODE..added.."|r waypoint(s) added.|r");
	else
		DEFAULT_CHAT_FRAME:AddMessage(YELLOW_FONT_COLOR_CODE.."Lost Treasure Check: No waypoints added.|r");
	end
end

---------
function LTC:CountCompleted(locationID)
---------

end

---------
function LTC:PrintHeader()
---------
	--LTC:PrintSeparatorLine();
	DEFAULT_CHAT_FRAME:AddMessage(YELLOW_FONT_COLOR_CODE.."Lost Treasure Check: |r");
	LTC:PrintSeparatorLine();
end

---------
function LTC:PrintFooter(completed)
---------
	--LTC:PrintSeparatorLine();
	DEFAULT_CHAT_FRAME:AddMessage(YELLOW_FONT_COLOR_CODE.."Total Treasures Found: |r"..completed.."/"..LTC_total);
	LTC:PrintSeparatorLine();
end

---------
function LTC:PrintSeparatorLine()
---------
	DEFAULT_CHAT_FRAME:AddMessage("---------------------------|r");
	end

---------
function LTC:PrintLocationHeader(locationID, total, completed)
---------
	DEFAULT_CHAT_FRAME:AddMessage(YELLOW_FONT_COLOR_CODE..GetMapNameByID(locationID).."|r ("..(total - completed).." of "..total..RED_FONT_COLOR_CODE.." missing|r): ");
end

---------
function LTC:PrintLocationFlags(locationID, flags, isCompleted, showCompleted)
---------
	for index,questID in ipairs(flags)
	do
		local link;
		local c = isCompleted[questID];
		local itemID = LTC:GetItemID(locationID, questID);
		local note = LTC:GetFlagNote(locationID, questID);

		if itemID ~= nil then
			link = LTC:GetItemLink(itemID);			
		end	

		if link == nil then
			link = LTC:GetFlagName(locationID, questID);
		end

		LTC:PrintFlagInfo(link, nil, c, showCompleted)
	end
end

---------
function LTC:PrintLocationFooter()
---------
	DEFAULT_CHAT_FRAME:AddMessage("\n");
end

---------
function LTC:PrintFlagInfo(link, note, isCompleted, showCompleted)
---------
	if not isCompleted then	
		if (note ~= nil) then
			DEFAULT_CHAT_FRAME:AddMessage(" - "..link.." - "..RED_FONT_COLOR_CODE.."missing!|r - "..note);
		else
			DEFAULT_CHAT_FRAME:AddMessage(" - "..link.." - "..RED_FONT_COLOR_CODE.."missing!|r");
		end
	elseif showCompleted then		
			DEFAULT_CHAT_FRAME:AddMessage(" - "..link.." - "..GREEN_FONT_COLOR_CODE.."found|r");
	end
end
---------
function LTC:GetItemID(locationID, questID)
---------
	return LTC_flags[locationID][questID]["itemID"];
end

---------
function LTC:GetFlagName(locationID, questID)
---------
	if (LTC_flags[locationID][questID]["name"] ~= nil) then
		return LTC_flags[locationID][questID]["name"];
	else
		return "";
	end
end

---------
function LTC:GetFlagCoords(locationID, questID)
---------
	
	if (LTC_flags[locationID][questID]["coords"] ~= nil) then
		return LTC_flags[locationID][questID]["coords"];
	else
		return nil
	end	
end

---------
function LTC:GetFlagNote(locationID, questID)
---------	
	if (LTC_flags[locationID][questID]["note"] ~= nil) then
		return LTC_flags[locationID][questID]["note"];
	else
		return "";
	end
	
	--local note = "";
	--if (LTC_flags[locationID][questID]["note"] ~= nil) then
		--note = LTC_flags[locationID][questID]["note"];
	--if questID < 0 then
		--note = note.." (unknown QuestID - cannot track completion) "
	--end
	
	--return note;
end

---------
function LTC:GetItemLink(itemID)
---------
	if (itemID ~= nil) then
		local itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount,itemEquipLoc, itemTexture, itemSellPrice = GetItemInfo(itemID);
		return itemLink;	
	else
		return nil;
	end
end
